<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Treydəki nişana vurun
və ya qısayolu yenidən basaraaq yazıkmanı dayandırın</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Yazılma zamanı ekranı döndərməyin</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Ekran şəkli</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Qeyd aparılır</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Yazmaq</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekran şəkli</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Ekran şəkli çəkmək</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Saxlanıla bilmədi. Lütfən onu ev qovluğunda saxlayın</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Görünüş</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Ekran şəkli çəkildi</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>sahə-seçimi</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Saxlamaq</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>%1 qovluğunda saxlamaq</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Gözardı etmək</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Mübadilə yaddaşı</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Ekran yazılması faylı saxlanılır, lütfən gösləyin...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>İşləmə zamanı pəncərə effekti söndürüldüyü üçün qeydə alma dayandırılmalıdır</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekran şəkli</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>Ekran şəkli çəkilə bilmədi.</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Sürüşdürmə</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Ekran şəkllərini sancaqlayın</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Qovluğu açın</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Ekran görüntüsü tamamlandı və klippordaya kopyaladı</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Qaytarın</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Saxlamaq</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıxış</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Ekran şəkllərini sancaqlayın</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Ekran şəkli</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Yazmaq</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Ekran şəkli</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Qeyd aparılır</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Görünüş</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Yazılma başa çatdı</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>%1 qovluğunda saxlamaq</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Yazmaq</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Qovluğu açın</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Ekran şəkli %1 saniyədən sonra çəkiləcək</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Kömək alın.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Kəsintisiz ekran şəklini saxlamaq baş tutmadı.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Sürüşdürmə sahəsinin aşağısına çatdı</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Maksimum hündürlüyə çatdı</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>Çəkim sahəsini təyin edin</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Siçan çarxını sürüşdürün və ya sürüşdürülənən ekran görüntüsü çəkmək üçün vurun</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Sürüşdürmə sürətini zəiflədin</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Səhv sahə, buraya vurun:</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Mətni buraya daxil edin</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Başlatmaq/Ekran şəkli</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Çıxış/Saxlamaq</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Ölçüsünü təyin edin</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Tez başlatmaq</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Pəncərənin şəkli</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Ekran şəkli müddəti</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Tam ekran şəkli</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıxış</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Saxlamaq</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Düzbucaqlı</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellips</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Xətt</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Qələm</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Mətn</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Silmək</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Qaytarın</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Hündürlüyü yuxarı artırın</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Hündürlüyü aşağı artırın</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Enini sola artırın</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Enini sağa artırın</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Hündürlüyü yuxarıdan azaldın</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Hündürlüyü aşağıdan azaldın</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Enini soldan azaldın</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Enini sağdan azaldın</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Kömək</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Ekran qısayolları</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Səs</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Düymə basılması</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Veb-kamera</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Yazmağa başlayın</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Seçimlər</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Başlatmaq/Yazılma</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Siçan</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Alətlər</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Mətni çıxarın</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Sürüşdürmə</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Ekran şəkllərini sancaqlayın</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>OCR-i başladın</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Sürüşdürməni başladın</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Ox</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Ekran şəkli</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Yazmaq</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Düzbucaqlı
Dördbucaqlı çəkmək üçün Shift düyməsini basıb saxlayın</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Ellips
Dairə çəkmək üçün Shift düyməsini basıb saxlayın</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Fırça
Düz xətt çəkmək üçün Shift düyməsini basıb saxlayın</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Bulanıqlıq səviyəsini təyin edin (Bunun üçün sürüşdürün)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Firçanın ölçüsünü təyin edin (Bunun üçün sürüşdürün)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Yazı ölçüsünü təyin edin (Bunu üçün sürüşdürün)</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click or drag to
select the area to record</source>
        <translation>Toxunub sürüşdürməklə
yazılacaq sahəni seçin</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Düymə basılması göstərilsin (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Düymə basılmasını gizlətmək (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Düymə basılması göstərilsin (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Kameranı açın (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Kameranı söndürün (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Ekran şəkli</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Ayarlar (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formatı:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Səs</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Sistem səsi</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Seçimlər</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Göstərici görünsün</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Klikləmə görünsün</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Belə saxlayın</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>İş Masası</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videolar</translation>
    </message>
    <message>
        <source>Rectangle (R)
Press and hold Shift to draw a square</source>
        <translation>Düzbucaqlı (R)
DDördbucaqlı çəkmək üçün Shift düyməsini basıb saxlayın</translation>
    </message>
    <message>
        <source>Ellipse (O)
Press and hold Shift to draw a circle</source>
        <translation>Ellips (O), 
Çevrə çəkmək üçün Shift düyməsini basıb saxlayın</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Xətt (L)
Üfüqi və ya şaquli xətt şəkmək üçün Shift düyməsini basıb saxlayın</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Ox (X)
Üfüqi və ya şaquli ox çəkmək üçün Shift düyməsini basıb saxlayın</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Qələm (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Bulanıq (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Mətn (M)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Sürüşdürmə (Alt+İ)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Mətni çıxarın (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Ekran şəklini sancaqla (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Geriyə (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Yazmaq</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Mübadilə yaddaşı</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Şəkillər</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Qovluq</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Saxlamaq üçün bir yol təyin edin</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Saxlamaq üçün yolu dəyişin</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Çərçivə effektləri</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Heç biri</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Kölgə</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Şərçivə</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Cihaz</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Mətni çıxarın</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Bağlayın (Esc)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>OLDU (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Daha yaxşı video effekti üçün %1*%2 daxilində yazılma sahəsini təyin edin</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Hal-hazırda ekranın video qeydi dəstəklənmir</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Çıxış</translation>
    </message>
</context>
<context>
    <name>VoiceRecordProcess</name>
    <message>
        <source>New recording</source>
        <translation>Yeni ekran qeydi</translation>
    </message>
</context>
</TS>
